pub struct LifecycleFilter {
pub prefix: Option<String>,
pub size_gt: Option<u64>,
pub size_lt: Option<u64>,
}Expand description
A lifecycle filter is a set of conditions that must all be true. For each condition, if it is None, it is not verified (always true), and if it is Some(x), then it is verified for value x
Fields
prefix: Option<String>If Some(x), object key has to start with prefix x
size_gt: Option<u64>If Some(x), object size has to be more than x
size_lt: Option<u64>If Some(x), object size has to be less than x